####
URLS
####

REGIONAAL TUCHTCOLLEGE VOOR DE GEZONDHEIDSZORG

* http://tuchtrecht.overheid.nl/zoeken/resultaat/uitspraak/2014/ECLI_NL_TGZRAMS_2014_94?zaaknummer=2013%2F221&Pagina=1&ItemIndex=1

Acute Geestelijke Gezondheidszorg: Knelpunten en verbetervoorstellen in de keten

* http://www.rijksoverheid.nl/documenten-en-publicaties/rapporten/2015/02/11/acute-geestelijke-gezondheidszorg-knelpunten-en-verbetervoorstellen-in-de-keten.html

F-ACT leid niet tot minder opnames

* http://mgv.boomtijdschriften.nl/artikelen/GV-67-6-319_Zorggebruik%20van%20patinten%20in%20ACT%20of%20FACT%20.html

"Hier vond men dat alleen in regio’s waar teams werkten met optimale 24-uursbereikbaarheid het aantal opnames met 20% verminderde en de opnameduur met 10% werd bekort. 
Regio’s met teams die deze 7*24 uur bereikbaarheid niet hadden georganiseerd, lieten geen reductie in aantal opnames of opnameduur zien."

* http://www.tijdschriftvoorpsychiatrie.nl/issues/434/articles/8318

24 uur per dag zorg in de nabijheid omdat hij zelf niet in staat is om op
relevante momenten hulp in te roepen

* http://www.psynip.nl/website-openbaar-themas/sector-gezondheidszorg/langdurige-zorg/2015035366-hhm-afwegingskader-concept-bestuurlijke-consultatie-1-povoopen.pdf

